//
//
// Version:  4.33.0
//
// Author:   korvtiger
//
// Template för ånglokshytter som använder sig av STLs ångloksscript.
// Se separat dokument för närmare detaljer.
//
// ****************************************************************************************************

include "STLSteamCabin.gs"

// ====================================================================================================

class ***ClassName*** isclass STLSteamCabin {
	
	
	public void Init(void) {
		inherited(); // Anropa STLSteamEngines Init, ha ingen kod ovan detta anrop!
		
		// Din kod här
		
		
		
		// Längden av halva vattenspegeln i pannan i meter. Används för beräkning av vattenståndsglasens missvisning.
		// Alltså hälften av längden mellan främre tubplåten och pannans bakkant.
		halfBoilerWaterMirrorLength = 3.0; // Default value, för lok med 6 meter lång vattenspegel.
	}

	
	/**
	 * Metod som anropas när en hytt byggs upp för ett lok som redan har haft en hytt. Här ska du återställa alla 
	 * reglage som du själv har definierat i detta script som du sparat ned statet på i CabinDatat i Detach metoden.
	 * STLs super-implementation av denna metod tar hand om att uppdatera de STL-inbyggda reglagen.
	 */
	public void UpdateCabinFromSavedData() {
		inherited(); // Se alltid till att anropa STLs implementation först!
		
		// Exempel:
		headlightSwitch.SetValue(cabinData.stateAsBool[0]);
		highBeamsSwitch.SetValue(cabinData.stateAsBool[1]);
		
		// Cabindata innehåller tre stycken arrayer med 16 element vardera som kan användas för att spara data
		// som är specifik för en hytt. Ingen av dessa arrayer kommer att röras av STLs script, så det är helt
		// upp till hyttbyggaren/scriptaren att använda dessa fritt. Se STLs ånglok för exempel på detta.
		// cabinData.stateAsBool[0]
		// cabinData.stateAsInt[0]
		// cabinData.stateAsFloat[0]
		
		
		// Metod som kan anropas för att köra en animation på den exteriöra lokmodellen till _procent_ av sin animationslängd.
		// Procent är ett värde från 0.0 till 1.0.
		SetExteriorAnimation(string meshName, float procent);
	}
	
	
	/**
	 * Metod som anropas när kronan öppnas eller stängs, samt då någon av de ventiler som sitter i kronan ändras.
	 */
	void UpdateKronan() {
		inherited(); // Se alltid till att anropa STLs implementation först!
		
		if((crown_main_valve and crown_main_valve.GetValue() > 0.5) {
			// Ångventilen till kronan är stängd (snabbavstängningen är utlöst)
			// (crown_main_value är 1 när den är stängd och 0 när den är öppen)
			
			// Stäng av alla apparater som är kopplade till kronan...
		}
		else {
			// Ångventilen till kronan är öppen
			// Kolla om individuella ventiler är öppna, uppdatera saker etc...
		}
	}
	
	
	/**
	 * This method is called by the cabin when the main switch of the cabin has changed.
	 * Use the cabinData.lightMainSwitch boolean to find ot the state of the main switch.
	 * This will not be called at startup, so for cabins without a main switch, this method will never be called.
	 */
	void OnLightMainSwitchChanged() {
		inherited(); // Se alltid till att anropa STLs implementation först!
		
		if(cabinData.lightMainSwitch) {
			// Huvudbrytaren har slagits på
		}
		else {
			// Huvudbrytaren är avstängd
		}
	}
	
	
	/**
	 * This method is called when the user changed the headlight or high beams state from the UI.
	 * The new headlight and high beams state can be read from cabinData.headlightOn and cabinData.highBeamsOn.
	 * The default implementation of this method will, if the light is turned on, start the turbo generator if the loco has one.
	 */
	void OnLightChangedFromUI() {
		inherited(); // Se alltid till att anropa STLs implementation först!
		
		// Uppdatera reglagen i hytten till att motsvara den nya ljusbilden
		// Exampel:
		headlightSwitch.SetValue(cabinData.headlightOn);
		highBeamsSwitch.SetValue(cabinData.highBeamsOn);
	}
	
	
 	public void Attach(GameObject obj) {
		inherited(obj);
		
		// Variabeln mySTLEngine kan användas för att anropa loket som denna hytt för tillfället tillhör. Notera att denna variabel kommer vara null före
		// Attach-metoden anropats, vilket innebär att den inte kan användas i Init (constuctorn).
		
		// Inbyggd metod för att hitta ett loks tender, returnerar null om ingen tender kopplad till loket kunde hittas.
		Vehicle tender = mySTLEngine.GetMyTender();

		// Your code here
	}
	
	
	public void Detach() {
		inherited();
		
		// Your code here
		// Example:
		cabinData.stateAsBool[0] = headlightSwitch.GetValue();
		cabinData.stateAsBool[1] = highBeamsSwitch.GetValue();
	}
	
	
	
};
